@@ -31,6 +31,8 @@ It supports Python 2 and Python 3.
 from __future__ import absolute_import
 
 import sys
+import logging
+
 from .cim_types import *  # noqa: F403,F401
 from .cim_constants import *  # noqa: F403,F401
 from .cim_operations import *  # noqa: F403,F401
@@ -38,11 +40,15 @@ from .cim_obj import *  # noqa: F403,F401
 from .tupleparse import *  # noqa: F403,F401
 from .cim_http import *  # noqa: F403,F401
 from .exceptions import *  # noqa: F403,F401
+from .mof_compiler import *  # noqa: F403,F401
+from ._valuemapping import *  # noqa: F403,F401
 from ._server import *  # noqa: F403,F401
 from ._subscription_manager import *  # noqa: F403,F401
 from ._listener import *  # noqa: F403,F401
 from ._recorder import *  # noqa: F403,F401
 from .config import *  # noqa: F403,F401
+from ._statistics import *  # noqa: F403,F401
+from ._logging import *  # noqa: F403,F401
 
 from ._version import __version__  # noqa: F401
 
@@ -52,3 +58,15 @@ if _python_m == 2 and _python_n < 6:
     raise RuntimeError('On Python 2, pywbem requires Python 2.6 or higher')
 elif _python_m == 3 and _python_n < 4:
     raise RuntimeError('On Python 3, pywbem requires Python 3.4 or higher')
+
+# On Python 2, add a NullHandler to suppress the warning "No handlers could be
+# found for logger ...".
+if _python_m == 2:
+    try:  # Python 2.7+ includes logging.NullHandler
+        from logging import NullHandler
+    except ImportError:
+        class NullHandler(logging.Handler):
+            """Implement logging NullHandler for Python 2.6"""
+            def emit(self, record):
+                pass
+    logging.getLogger('pywbem').addHandler(NullHandler())
